//----------------------------------------------------------------------------
//
// Module:
//   ebmsg
//
// Description:
//   ProASICPLUS design for ACTEL eval board
//
// $Log$
// $Id$
//
// Copyright (C) 2002 ACTEL CORP.  All rights reserved.
//----------------------------------------------------------------------------

module ebmsg (
   clkpad,
   fa,    
   fd,    
   nfcs,  
   nfrd,  
   nfwr
);

// system connections
input  clkpad;         // input clock, 4MHz

// Interface to dual-port RAM for keypad and display
output [12:0] fa;      // addr bus
inout  [7:0] fd;       // data bus
output nfcs;           // chip select
output nfrd;           // output enable
output nfwr;           // write strobe

//***************************************************************************
//
// Local signals
//
//***************************************************************************
wire clk1x;            // 1x system clock generated from PLL

reg [7:0] lcdstate;
reg [12:0] fa;
reg [7:0] fdreg;   
reg nfwr;
reg nfrd;

//***************************************************************************
//
// PLL to generate system clocks
//
//***************************************************************************
pll1x _pll1x (
   .CLK(clkpad),
   .GLB(clk1x),
   .LOCK()
);

//***************************************************************************
//
// Write continuously to LCD
//
//***************************************************************************

assign nfcs = 1'b0;
assign fd = lcdstate[7] ? 8'hZZ : fdreg;

always @(posedge clk1x) begin
   lcdstate <= lcdstate+1;

   if (lcdstate[7]) nfwr <= 1'b1;
   else case (lcdstate[1:0])
      2'b00:  nfwr <= 1'b1;
      2'b01:  nfwr <= 1'b0;
      2'b10:  nfwr <= 1'b0;
      2'b11:  nfwr <= 1'b1;
   endcase

   fa <= {7'b0000000, lcdstate[7:2]};
    


   case (lcdstate[6:2])
      5'h00:  fdreg <= 8'h20;    // ' '
      5'h01:  fdreg <= 8'h41;    // 'A'
      5'h02:  fdreg <= 8'h43;    // 'C'
      5'h03:  fdreg <= 8'h54;    // 'T'
      5'h04:  fdreg <= 8'h45;    // 'E'
      5'h05:  fdreg <= 8'h4c;    // 'L'
      5'h06:  fdreg <= 8'h20;    // ' '
      5'h07:  fdreg <= 8'h50;    // 'P'
      5'h08:  fdreg <= 8'h52;    // 'R'
      5'h09:  fdreg <= 8'h4f;    // 'O'
      5'h0A:  fdreg <= 8'h56;    // 'V'
      5'h0B:  fdreg <= 8'h49;    // 'I'
      5'h0C:  fdreg <= 8'h44;    // 'D'
      5'h0D:  fdreg <= 8'h45;    // 'E'
      5'h0E:  fdreg <= 8'h53;    // 'S'
      5'h0F:  fdreg <= 8'h20;    // ' '
      5'h10:  fdreg <= 8'h50;    // 'P'
      5'h11:  fdreg <= 8'h52;    // 'R'
      5'h12:  fdreg <= 8'h4f;    // 'O'
      5'h13:  fdreg <= 8'h41;    // 'A'
      5'h14:  fdreg <= 8'h53;    // 'S'
      5'h15:  fdreg <= 8'h49;    // 'I'
      5'h16:  fdreg <= 8'h43;    // 'C'
      5'h17:  fdreg <= 8'h50;    // 'P'
      5'h18:  fdreg <= 8'h4c;    // 'L'
      5'h19:  fdreg <= 8'h55;    // 'U'
      5'h1A:  fdreg <= 8'h53;    // 'S'
      5'h1B:  fdreg <= 8'h20;    // ' '
      5'h1C:  fdreg <= 8'h20;    // ' '
      5'h1D:  fdreg <= 8'h20;    // ' '
      5'h1E:  fdreg <= 8'h20;    // ' '
      5'h1F:  fdreg <= 8'h20;    // ' '
   endcase

   if (~lcdstate[7]) nfrd <= 1'b1;
   else case (lcdstate[1:0])
      2'b00:  nfrd <= 1'b1;
      2'b01:  nfrd <= 1'b0;
      2'b10:  nfrd <= 1'b0;
      2'b11:  nfrd <= 1'b1;
   endcase 
// states 80..FF read memory but nothing is done with the data.
end

endmodule
